@@ -13,7 +13,9 @@ from typing import Optional, Set, Dict
 import psutil
 
 import docker
+from codalab.lib.telemetry_util import capture_exception, using_sentry
 import codalab.worker.docker_utils as docker_utils
+import requests
 
 from .bundle_service_client import BundleServiceException, BundleServiceClient
 from .dependency_manager import DependencyManager
@@ -151,7 +153,14 @@ class Worker:
         # that might have been created by other workers.
         try:
             self.docker.networks.prune(filters={"until": "1h"})
-        except docker.errors.APIError as e:
+        except (docker.errors.APIError, requests.exceptions.ReadTimeout) as e:
+            # docker.errors.APIError is raised when a prune is already running:
+            # https://github.com/codalab/codalab-worksheets/issues/2635
+            # docker.errors.APIError: 409 Client Error: Conflict ("a prune operation is already running").
+            # requests.exceptions.ReadTimeout is raised when the request to the Docker socket times out.
+            # https://github.com/docker/docker-py/issues/2266
+            # Since pruning is a relatively non-essential routine (i.e., it's ok if pruning fails
+            # on one or two iterations), we just ignore this issue.
             logger.warning("Cannot prune docker networks: %s", str(e))
 
         # Right now the suffix to the general worker network is hardcoded to manually match the suffix
@@ -251,16 +260,22 @@ class Worker:
                     self.terminate = True
             except Exception:
                 self.last_checkin_successful = False
+                if using_sentry():
+                    capture_exception()
                 traceback.print_exc()
                 if self.exit_on_exception:
-                    logger.error('Encountered exception, terminating the worker...')
+                    logger.warning(
+                        'Encountered exception, terminating the worker after sleeping for 5 minutes...'
+                    )
                     self.terminate = True
+                    # Sleep for 5 minutes
+                    time.sleep(5 * 60)
                 else:
                     # Sleep for a long time so we don't keep on failing.
-                    # We sleep in 5-second increments, itermittently checking
+                    # We sleep in 5-second increments to check
                     # if the worker needs to terminate (say, if it's received
                     # a SIGTERM signal).
-                    logger.error('Sleeping for 1 hour due to exception...please help me!')
+                    logger.warning('Sleeping for 1 hour due to exception...please help me!')
                     for _ in range(12 * 60):
                         # We run this here, instead of going through another iteration of the
                         # while loop, to minimize the code that's run---the reason we ended up here
@@ -299,7 +314,7 @@ class Worker:
             self.docker_network_internal.remove()
             self.docker_network_external.remove()
         except docker.errors.APIError as e:
-            logger.error("Cannot clear docker networks: %s", str(e))
+            logger.warning("Cannot clear docker networks: %s", str(e))
 
         logger.info("Stopped Worker. Exiting")
 
@@ -393,7 +408,7 @@ class Worker:
                 logger.info('Connected! Successful check in!')
             self.last_checkin_successful = True
         except BundleServiceException as ex:
-            logger.error("Disconnected from server! Failed check in: %s", ex)
+            logger.warning("Disconnected from server! Failed check in: %s", ex)
             if not self.last_checkin_successful:
                 logger.info(
                     "Checkin failed twice in a row, sleeping %d seconds", self.CHECKIN_COOLDOWN
